Development documentation — Poezio 0.9-dev documentation

# Development documentation

## About plugins

- Plugin API documentation
  - BasePlugin
  - PluginAPI
  - Example plugins
- Event Index
- SleekXMPP classes
- XEP

## About Poezio

- Overview
  - Global overview
  - Event handlers
  - Commands and completion
    - Dealing with the command line
- Contributing
  - Conventions
  - Commit guidelines
  - Getting your code into poezio
- Theming module
- Timed events documentation
- Common operations documentation